@@ -4,7 +4,7 @@
 #include <skalibs/avlnode.h>
 #include <skalibs/avltreen.h>
 
-void avltreen_init (avltreen *t, avlnode *storage, uint32_t *freelist, uint32_t size, dtokfunc_t_ref dtok, cmpfunc_t_ref f, void *p)
+void avltreen_init (avltreen *t, avlnode *storage, uint32_t *freelist, uint32_t size, dtok_func_ref dtok, cmp_func_ref f, void *p)
 {
   GENSET_init(&t->x, avlnode, storage, freelist, size) ;
   t->root = size ;
