@@ -5,10 +5,10 @@
 #include <skalibs/avltree.h>
 #include <skalibs/bigkv.h>
 
-void bigkv_free (bigkv_t *b)
+void bigkv_free (bigkv *b)
 {
   avltree_free(&b->map) ;
-  genalloc_free(bigkv_node_t, &b->nodes) ;
+  genalloc_free(bigkv_node, &b->nodes) ;
   stralloc_free(&b->storage) ;
   *b = bigkv_zero ;
 }
