@@ -5,8 +5,9 @@
 
 int alloc_realloc (char **x, size_t n)
 {
-  char *y = n ? (char *)realloc(*x, n) : (free(*x), (char *)alloc(0)) ;
+  char *y = n ? realloc(*x, n) : alloc(0) ;
   if (!y) return 0 ;
+  if (!n) free(*x) ;
   *x = y ;
   return 1 ;
 }
