@@ -3,7 +3,7 @@
 #include <skalibs/uint32.h>
 #include <skalibs/djbtime.h>
 
-size_t localtmn_fmt (char *s, localtmn_t const *l)
+size_t localtmn_fmt (char *s, localtmn const *l)
 {
   char *p = s ;
   p += localtm_fmt(p, &l->tm) ; *p++ = '.' ;
