@@ -6,5 +6,5 @@
 int ndelay_on (int fd)
 {
   int got = fcntl(fd, F_GETFL) ;
-  return (got == -1) ? -1 : fcntl(fd, F_SETFL, got | O_NONBLOCK) ;
+  return got < 0 ? got : got & O_NONBLOCK ? 0 : fcntl(fd, F_SETFL, got | O_NONBLOCK) ;
 }
