@@ -4,7 +4,7 @@
 #include <skalibs/uint64.h>
 #include <skalibs/djbtime.h>
 
-int tai_from_localtm (tai_t *t, struct tm const *l)
+int tai_from_localtm (tai *t, struct tm const *l)
 {
   uint64_t u ;
   if (!ltm64_from_localtm(&u, l)) return 0 ;
