@@ -5,7 +5,7 @@
 #include <time.h>
 #include <skalibs/tai.h>
 
-int tai_now (tai_t *t)
+int tai_now (tai *t)
 {
   time_t u = time(0) ;
   if (u == (time_t)-1) return 0 ;
