@@ -2,4 +2,4 @@
 
 #include <skalibs/tai.h>
 
-tain_t const tain_nano500 = TAIN_NANO500 ;
+tain const tain_nano500 = TAIN_NANO500 ;
