@@ -9,12 +9,18 @@
 #endif
 
 #include <skalibs/nonposix.h>
+
+#include <errno.h>
 #include <fcntl.h>
+
 #include <skalibs/unix-transactional.h>
 
 int open3_at (int dirfd, char const *file, int flags, unsigned int mode)
 {
-  return openat(dirfd, file, flags, mode) ;
+  int fd ;
+  do fd = openat(dirfd, file, flags, mode) ;
+  while (fd == -1 && errno == EINTR) ;
+  return fd ;
 }
 
 #else
