@@ -3,7 +3,7 @@
 #include <skalibs/djbunix.h>
 #include <skalibs/unixmessage.h>
 
-void unixmessage_drop (unixmessage_t const *m)
+void unixmessage_drop (unixmessage const *m)
 {
   unsigned int i = m->nfds ;
   while (i--) fd_close(m->fds[i]) ;
